# CHANGELOG


## v0.3.0 (2025-09-05)

### Bug Fixes

- Argument type for validation schema
  ([`5549f4e`](https://github.com/RomainGiraud/projects-organizer/commit/5549f4e3eec13522ba8d3e9aa1caf0655a4ff2ef))

- Handle return value correctly
  ([`35712ab`](https://github.com/RomainGiraud/projects-organizer/commit/35712abfd7145727451693c8499cb94f79dc04b2))

fix tests

- Types and format
  ([`f418271`](https://github.com/RomainGiraud/projects-organizer/commit/f41827183d34a9228461996a0aebb9cc10661af1))

- Use more the verbose option
  ([`8d3847f`](https://github.com/RomainGiraud/projects-organizer/commit/8d3847f05aa937be9c6016baced016e2a408e6c2))

- Validate basedir argument
  ([`5e96596`](https://github.com/RomainGiraud/projects-organizer/commit/5e9659602fc6381683f0c871ed132af8ec5bde44))

- **validate**: Check schema correctness
  ([`5ee802f`](https://github.com/RomainGiraud/projects-organizer/commit/5ee802ffed938891fd0efee06ca0ddd8fa6d095d))

### Features

- Display all errors
  ([`08d3204`](https://github.com/RomainGiraud/projects-organizer/commit/08d3204f1d4bf6d4673e839fb7fc52561c6f756e))

Instead of the first one

### Refactoring

- Add log error function
  ([`8e178b4`](https://github.com/RomainGiraud/projects-organizer/commit/8e178b4dd302ff179ef8cab28ed12c7b9f3a739c))

- Clean comments
  ([`de21614`](https://github.com/RomainGiraud/projects-organizer/commit/de216143aabf60a4d29167ff20498d4770b3d706))

- Remove cleanup function
  ([`8e500c3`](https://github.com/RomainGiraud/projects-organizer/commit/8e500c3e2b1f6f84368721efbc7f504d15a58252))

- **list**: Remove specialized options
  ([`5c448bd`](https://github.com/RomainGiraud/projects-organizer/commit/5c448bd4399bba0917874fb22a2c46c7ba15d243))

### Testing

- Add tests to cover all the source
  ([`1798ba1`](https://github.com/RomainGiraud/projects-organizer/commit/1798ba1a8baad5bffbb9c23c789460dc982c2f5c))


## v0.2.0 (2025-09-05)

### Build System

- Add basedpyright
  ([`58d371f`](https://github.com/RomainGiraud/projects-organizer/commit/58d371f405003bef6f597361d3cb95a7761f5941))

- Add ruff
  ([`b646bc8`](https://github.com/RomainGiraud/projects-organizer/commit/b646bc8fad1bfb69c8b4081a485047b782e063c6))

- Add semantic-release
  ([`0856abb`](https://github.com/RomainGiraud/projects-organizer/commit/0856abbc6cfc018d85d5e903624e88935aac5151))

- Add test coverage
  ([`f1d0a06`](https://github.com/RomainGiraud/projects-organizer/commit/f1d0a064539f1cb810bffb115e03314a736842be))

- Add test workflow
  ([`0d0fd00`](https://github.com/RomainGiraud/projects-organizer/commit/0d0fd00c7c599024bb3d4af05cfb3db75c1fd1f4))

### Features

- Add tests
  ([`5cf918d`](https://github.com/RomainGiraud/projects-organizer/commit/5cf918dcf74567c3f80de614c60d6305be6f634b))

- Add version option
  ([`221e026`](https://github.com/RomainGiraud/projects-organizer/commit/221e026f90e539d7a87c147e95cc9ce0943ada53))

- Test Github actions
  ([`7907563`](https://github.com/RomainGiraud/projects-organizer/commit/790756375a9327ba3bbacf1da45bd6e8a7362870))

### Testing

- Add for list command
  ([`5948642`](https://github.com/RomainGiraud/projects-organizer/commit/5948642576698bcfbad180eec0eabea4a15e969a))


## v0.1.0 (2025-05-14)
